eqc_ex v1.4.2 EQC.Cluster
This module contains macros to be used with Quviq
QuickCheck. It defines Elixir versions of the Erlang
macros found in eqc/include/eqc_cluster.hrl. For detailed documentation of the
macros, please refer to the QuickCheck documentation.
Copyright (C) Quviq AB, 2014-2016.
Summary
Functions
Same as :eqc_component.pretty_commands/4 but takes a keyword list with
:history, :state, and :result instead of a tuple as the third argument
Same as :eqc_cluster.run_commands/2 but returns a keyword list with
:history, :state, and :result instead of a tuple
Same as :eqc_cluster.run_commands/3 but returns a keyword list with
:history, :state, and :result instead of a tuple
Macros
Generate a weight function given a keyword list of component names and weights
Functions
Same as :eqc_component.pretty_commands/4 but takes a keyword list with
:history, :state, and :result instead of a tuple as the third argument.
Same as :eqc_cluster.run_commands/2 but returns a keyword list with
:history, :state, and :result instead of a tuple.