eqc_ex v1.4.2 Mix.Tasks.Eqc
A Mix task for running QuickCheck properties. At the moment, this basically calls mix test with the given options.
Options
--only property- Default is to run all tests, also ExUnit tests, but this flag picks only the properties to run--only check- Runs specific test cases annotated by @check and does not generate new QuickCheck values for properties.--numtests n- Runsntests for each property.--morebugs- Activates more_bugs where appropriate.--showstates- Show intermediate states in failing State Machine properties.
Examples
mix eqc
Summary
Functions
Callback implementation for Mix.Task.run/1
Functions
Callback implementation for Mix.Task.run/1.